#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sockaddr
version:              0.0.1
visibility:           public
id:                   sockaddr-0.0.1-F1mZguCcbZELnsCdA8A4Z3
key:                  sockaddr-0.0.1-F1mZguCcbZELnsCdA8A4Z3
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Printing SockAddr
description:          Printing SockAddr
category:             Network
abi:                  8434f998a5c2febd91a0a6c8fc89d2fd
exposed:              True
exposed-modules:      Network.SockAddr
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sockaddr
hs-libraries:         HSsockaddr-0.0.1-F1mZguCcbZELnsCdA8A4Z3
depends:
    base-4.18.2.1 byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
    bytestring-0.11.5.3 network-3.1.4.0-Dw21gcQ0zRE10R3MPv5g8s

haddock-interfaces:   /usr/share/doc/haskell-sockaddr/html/sockaddr.haddock
haddock-html:         /usr/share/doc/haskell-sockaddr/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

